@@ -8,7 +8,7 @@
  * memorandum "A Kernel Model for Precision Timekeeping" by Dave Mills,
  * revised 31 January 1996. That document updates RFC1589.
  *
- * This program has been updated to use the new PPS API
+ * This program has been updated to use the new PPS API (draft-05, 1999-08-17)
  *
  * Copyright (c) 1996 - 1999 by Ulrich Windl
  *
@@ -26,7 +26,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: enable_pps.c,v 1.33 1999/10/03 14:43:57 windl Exp $
+ * $Id: enable_pps.c,v 1.34 1999/10/10 14:07:07 windl Exp $
  */
 #include	<unistd.h>
 #include	<stdlib.h>
@@ -84,7 +84,7 @@
 #define	BITS_OFF(v, b)			((v) & ~(b))
 #define	BITS_ON(v, b)			((v) | (b))
 
-static	const char	id[] = "$Id: enable_pps.c,v 1.33 1999/10/03 14:43:57 windl Exp $";
+static	const char	id[] = "$Id: enable_pps.c,v 1.34 1999/10/10 14:07:07 windl Exp $";
 
 #define	BIT(n)	(1UL << (n))
 #define OPT_MONITOR		BIT(0)	/* perform monitor loop */
@@ -250,11 +250,13 @@ static	int	pps_status(const char *tag, const int show_event,
 static	int	update_clock_info(struct clock_info *cip)
 {
 	static struct clock_info	last;
+	static struct timespec	sleeper = {0, 0};
 	int	result = -1;
 
 	cip->tx.modes = 0;
 	cip->state = adjtimex(&cip->tx);
-	if ( time_pps_fetch(ppshandle, &cip->info) == -1 )
+	if ( time_pps_fetch(ppshandle, PPS_TSFMT_TSPEC,
+			    &cip->info, &sleeper) == -1 )
 	{
 		perror("time_pps_fetch()");
 		memset(&cip->info, 0, sizeof(cip->info));
@@ -567,7 +569,11 @@ static	void	act_wait(struct clock_info *cip)
 	static struct timespec	sleeper = {5, 0};
 	pps_info_t		buf;
 
-	time_pps_wait(ppshandle, &sleeper, &buf);
+	if ( time_pps_fetch(ppshandle, PPS_TSFMT_TSPEC, &buf, &sleeper) != 0 )
+	{
+		perror("time_pps_fetch()");
+		memset(&buf, 0, sizeof(buf));
+	}
 }
 
 static monitor_t	monitors[] = {
@@ -604,7 +610,12 @@ static	void	monitor_jitter(struct clock_info *cip)
 	cip->tx.modes = 0;
 	while ( 1 )
 	{
-		time_pps_wait(ppshandle, NULL, &buf);
+		if ( time_pps_fetch(ppshandle, PPS_TSFMT_TSPEC,
+				    &buf, NULL) != 0 )
+		{
+			perror("time_pps_fetch()");
+			continue;
+		}
 		update_clock_info(cip);
 		if ( cip->seq == last.seq )
 			continue;
@@ -653,6 +664,7 @@ int	main(int argc, char *argv[])
 	int		stat = TIOCM_RTS;	/* RTS MODEM control line */
 	struct clock_info ci;
 	pps_params_t	parm;
+	int		kc_edge = 0;
 	int		ch;
 
 	fprintf(stderr,
@@ -780,12 +792,12 @@ int	main(int argc, char *argv[])
 	switch ( trigger )
 	{
 	case 'A':
-		parm.mode |= PPS_HARDPPSONASSERT;	/* fall through */
+		kc_edge |= PPS_CAPTUREASSERT;	/* fall through */
 	case 'a':
 		parm.mode |= PPS_CAPTUREASSERT;
 		break;
 	case 'C':
-		parm.mode |= PPS_HARDPPSONCLEAR;	/* fall through */
+		kc_edge |= PPS_CAPTURECLEAR;	/* fall through */
 	case 'c':
 		parm.mode |= PPS_CAPTURECLEAR;
 		break;
@@ -796,6 +808,7 @@ int	main(int argc, char *argv[])
 		break;
 	}
 
+	parm.api_version = PPS_API_VERS_1;
 	if ( time_pps_setparams(ppshandle, &parm) != 0 )
 	{
 		perror("time_pps_setparams()");
@@ -804,9 +817,28 @@ int	main(int argc, char *argv[])
 		/* continue, maybe just monitoring */
 	}
 	else
+	{
 		fprintf(stderr,
-			"PPS API set up (handle %d, mode %#04x)\n",
-			ppshandle, parm.mode);
+			"PPS API v%d set up (handle %d, mode %#04x)\n",
+			parm.api_version, ppshandle, parm.mode);
+		if ( kc_edge != 0 )
+		{
+			if ( time_pps_kcbind(ppshandle, PPS_KC_HARDPPS,
+					     kc_edge, PPS_TSFMT_TSPEC) != 0 )
+			{
+				perror("time_pps_kcbind()");
+				fprintf(stderr, "handle=%d, edge=%#04x\n",
+					ppshandle, kc_edge);
+				/* continue, maybe just monitoring */
+			}
+			else
+			{
+				fprintf(stderr,
+					"kernel consumer set (edge %#04x)\n",
+					kc_edge);
+			}
+		}
+	}
 	memset(&ci, 0, sizeof(ci));
 	update_clock_info(&ci);
 	print_header();
